@@ -24,10 +24,10 @@ sys.path.insert(0, os.path.abspath('../../apollinaire'))
  
 autodoc_mock_imports = ['numpy', 'scipy', 'matplotlib', 'matplotlib.pyplot',
                         'scipy.optimize', 'matplotlib.ticker', 'corner', 'emcee', 'pandas', 'astropy',
-                        'numdifftools', 'george', 'tqdm', 'dill', 'pathos', 'pathos.multiprocessing',
-                        'h5py', 'statsmodels.nonparametric.smoothers_lowess', 'pycorrelate', 'numba',
+                        'george', 'tqdm', 'dill', 'pathos', 'pathos.multiprocessing',
+                        'h5py', 'statsmodels.nonparametric.smoothers_lowess', 'numba',
                         'scipy.io', 'statsmodels', 'np', 'pd', 'plt', 'scipy.interpolate',
-                        'astropy.stats', 'scipy.signal', 'joblib']
+                        'astropy.stats', 'scipy.signal']
 
 # -- Project information -----------------------------------------------------
 
